==> apache-camel-quarkus-2.13.3-src.zip: camel-quarkus-2.13.3/integration-tests/json-validator/src/main/java/org/apache/camel/quarkus/component/json/validator/it/JsonValidatorRoute.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.json.validator.it;

import javax.enterprise.context.ApplicationScoped;

import org.apache.camel.ValidationException;
import org.apache.camel.builder.RouteBuilder;

@ApplicationScoped
public class JsonValidatorRoute extends RouteBuilder {

    @Override
    public void configure() {
        from("direct:validate-json").doTry().to("json-validator:schema.json").setBody(constant("valid"))
                .doCatch(ValidationException.class).setBody(constant("invalid")).end();

        from("direct:validate-json-from-header").doTry().to("json-validator:schema.json?headerName=headerToValidate")
                .setBody(constant("valid-header"))
                .doCatch(ValidationException.class).setBody(constant("invalid-header")).end();
    }
}

==> apache-camel-quarkus-3.15.4-src.zip: camel-quarkus-3.15.4/integration-tests/json-validator/src/main/java/org/apache/camel/quarkus/component/json/validator/it/JsonValidatorRoute.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.json.validator.it;

import jakarta.enterprise.context.ApplicationScoped;
import org.apache.camel.ValidationException;
import org.apache.camel.builder.RouteBuilder;

@ApplicationScoped
public class JsonValidatorRoute extends RouteBuilder {

    @Override
    public void configure() {
        from("direct:validate-json").doTry().to("json-validator:schema.json").setBody(constant("valid"))
                .doCatch(ValidationException.class).setBody(constant("invalid")).end();

        from("direct:validate-json-from-header").doTry().to("json-validator:schema.json?headerName=headerToValidate")
                .setBody(constant("valid-header"))
                .doCatch(ValidationException.class).setBody(constant("invalid-header")).end();
    }
}
